import inspect


class BaseModel:
    def __init__(self, *args, **kwargs):
        for key, value in kwargs.items():
            setattr(self, key, value)

    def get_parameters(self):
        members = inspect.getmembers(self, lambda x: not (inspect.isroutine(x)))
        return {param[0]: param[1] for param in members if not (param[0].startswith('_'))}

    def __str__(self):
        return str(self.get_parameters())


class Address(BaseModel):
    pass


class Country(BaseModel):
    pass


class City(BaseModel):
    pass


class Township(BaseModel):
    pass


class District(BaseModel):
    pass


class RetailStoreGroup(BaseModel):
    pass


class RetailStore(BaseModel):
    pass


class RelatedRetailStore(BaseModel):
    pass


class RetailStoreType(BaseModel):
    pass


class ShippingCost(BaseModel):
    pass


class Application(BaseModel):
    pass


class ApplicationGroup(BaseModel):
    pass


class ApplicationPermission(BaseModel):
    pass


class ApplicationGroupPermission(BaseModel):
    pass


class PriceList(BaseModel):
    pass


class ProductPrice(BaseModel):
    pass


class StockList(BaseModel):
    pass


class ProductStock(BaseModel):
    pass


class PriorityList(BaseModel):
    pass


class ProductPriority(BaseModel):
    pass


class CatalogItem(BaseModel):
    pass


class Catalog(BaseModel):
    pass


class CategoryNode(BaseModel):
    pass


class ProductCategory(BaseModel):
    pass


class CategoryTree(BaseModel):
    pass


class SchemaType(BaseModel):
    pass


class CategoryMappingGroup(BaseModel):
    pass


class CategoryMapping(BaseModel):
    pass


class Channel(BaseModel):
    pass


class CatalogFeedConf(BaseModel):
    pass


class IntegrationAction(BaseModel):
    pass


class IntegrationMapping(BaseModel):
    pass


class ChannelAttributeSet(BaseModel):
    pass


class ChannelAttributeSetConfig(BaseModel):
    pass


class ChannelAttributeSchema(BaseModel):
    pass


class ChannelAttribute(BaseModel):
    pass


class ChannelAttributeConfig(BaseModel):
    pass


class ChannelAttributeValue(BaseModel):
    pass


class ChannelAttributeValueConfig(BaseModel):
    pass


class DataSource(BaseModel):
    pass


class Customer(BaseModel):
    pass


class PanelTranslation(BaseModel):
    pass


class ErrorReport(BaseModel):
    pass


class LoyaltyTransaction(BaseModel):
    pass


class Mapping(BaseModel):
    pass


class Order(BaseModel):
    pass


class OrderItem(BaseModel):
    pass


class Promotion(BaseModel):
    pass


class DiscountItem(BaseModel):
    pass


class BenefitApplicant(BaseModel):
    pass


class ConditionApplicant(BaseModel):
    pass


class Transaction(BaseModel):
    pass


class PayOnDeliveryTransaction(BaseModel):
    pass


class FundsTransferTransaction(BaseModel):
    pass


class BexTransaction(BaseModel):
    pass


class CashRegisterTransaction(BaseModel):
    pass


class CargoCompany(BaseModel):
    pass


class OrderShippingInfo(BaseModel):
    pass


class CancellationRequest(BaseModel):
    pass


class CancellationEasyReturn(BaseModel):
    pass


class CancellationReason(BaseModel):
    pass


class OrderTransaction(BaseModel):
    pass


class CancellationPlan(BaseModel):
    pass


class CancellationPlanOrderItem(BaseModel):
    pass


class DiscountItemCancellationPlan(BaseModel):
    pass


class OrderExternalStatus(BaseModel):
    pass


class VendorOrder(BaseModel):
    pass


class VendorOrderItem(BaseModel):
    pass


class Reconciliation(BaseModel):
    pass


class Invoice(BaseModel):
    pass


class PaymentInvoiceItem(BaseModel):
    pass


class InvoiceItem(BaseModel):
    pass


class Pos(BaseModel):
    pass


class Bank(BaseModel):
    pass


class CardType(BaseModel):
    pass


class Card(BaseModel):
    pass


class BinNumber(BaseModel):
    pass


class Installment(BaseModel):
    pass


class PaymentOption(BaseModel):
    pass


class BankAccount(BaseModel):
    pass


class GroupProductItem(BaseModel):
    pass


class Product(BaseModel):
    pass


class Attribute(BaseModel):
    pass


class AttributeValue(BaseModel):
    pass


class AttributeSet(BaseModel):
    pass


class AttributeConfig(BaseModel):
    pass


class ERPCategory(BaseModel):
    pass


class AttributeLanguage(BaseModel):
    pass


class ProductImage(BaseModel):
    pass


class DownloadableImage(BaseModel):
    pass


class SpecialImage(BaseModel):
    pass


class Brand(BaseModel):
    pass


class ProductVideo(BaseModel):
    pass


class BundleChapterProduct(BaseModel):
    pass


class BundleChapter(BaseModel):
    pass


class ProductCollection(BaseModel):
    pass


class ProductCollectionItem(BaseModel):
    pass


class ReportingLog(BaseModel):
    pass


class SortingAlgorithm(BaseModel):
    pass


class SortOptionAlgorithm(BaseModel):
    pass


class SortOption(BaseModel):
    pass


class ProductSortingItem(BaseModel):
    pass


class UserProfile(BaseModel):
    pass


class User(BaseModel):
    pass


class BEPermissionNamespace(BaseModel):
    pass


class BEPermission(BaseModel):
    pass


class FEPermissionGroup(BaseModel):
    pass


class FEPermission(BaseModel):
    pass


class CatalogGroup(BaseModel):
    pass


class ChannelGroup(BaseModel):
    pass


class BatchRequest(BaseModel):
    pass


class ContentType(BaseModel):
    pass



from omnisdk.api_endpoint import ApiEndpoint
from omnisdk.omnitron.models import *


class OmnitronApiEndpoint(ApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(api_class_name="OmnitronApiClient", *args, **kwargs)


class ProductEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="products", model=Product, *args, **kwargs)


class CatalogEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="catalogs", model=Catalog, *args, **kwargs)


class ChannelEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channels", model=Channel, *args, **kwargs)


class ActiveUserEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint='active_user', model=User, *args, **kwargs)


class OrderByNumberEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="order_number", model=Order, *args, **kwargs)


class OrderItemEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="order_items", model=OrderItem,
                         *args, **kwargs)


class PaymentOptionEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="payment_options", model=PaymentOption,
                         *args, **kwargs)


class TransactionEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="transactions",
                         model=Transaction, *args, **kwargs)


class OrderTransactionEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="order_transactions",
                         model=OrderTransaction, *args, **kwargs)


class PayOnDeliveryTransactionEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="pay_on_delivery_transactions",
                         model=PayOnDeliveryTransaction, *args, **kwargs)


class LoyaltyTransactionEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="loyalty_transactions",
                         model=LoyaltyTransaction, *args, **kwargs)


class FundsTransferTransactionEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="funds_transfer_transactions",
                         model=FundsTransferTransaction, *args, **kwargs)


class BexTransactionEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="bex_transactions",
                         model=BexTransaction, *args, **kwargs)


class ChannelCategoryTreeEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/category_trees",
                         model=CategoryTree, *args, **kwargs)


class ChannelCategoryNodeEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/category_nodes",
                         model=CategoryNode, *args, **kwargs)


class ChannelCancellationReasonEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/cancellation_reasons",
                         model=CancellationReason, *args, **kwargs)


class ChannelCancellationRequestEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/cancellation_requests",
                         model=CancellationRequest, *args, **kwargs)


class ChannelAttributeSetConfigEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/attribute_set_configs",
                         model=ChannelAttributeSetConfig, *args, **kwargs)


class ChannelAttributeSetEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/attribute_sets",
                         model=ChannelAttributeSet, *args, **kwargs)


class ChannelAttributeEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/attributes",
                         model=ChannelAttribute, *args, **kwargs)


class ChannelAttributeSchemaEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/attribute_schemas",
                         model=ChannelAttributeSchema, *args, **kwargs)


class ChannelAttributeConfigEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/attribute_configs",
                         model=ChannelAttributeConfig, *args, **kwargs)


class ChannelAttributeValueEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/attribute_values",
                         model=ChannelAttributeValue, *args, **kwargs)


class ChannelAttributeValueConfigEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/attribute_value_configs",
                         model=ChannelAttributeValueConfig, *args, **kwargs)


class CatalogItemEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="catalog_items",
                         model=CatalogItem, *args, **kwargs)


class ChannelBatchRequestEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/batch_requests",
                         model=BatchRequest, *args, **kwargs)


class ChannelProductEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/products",
                         model=Product, *args, **kwargs)


class ContentTypeEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="content_types",
                         model=ContentType, *args, **kwargs)


class ChannelIntegrationActionEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/integration_actions",
                         model=IntegrationAction, *args, **kwargs)


class ChannelProductPriceEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/product_prices",
                         model=ProductPrice, *args, **kwargs)


class ChannelProductStockEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/product_stocks",
                         model=ProductStock, *args, **kwargs)


class ChannelMappedProductEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/mapped_products",
                         model=Product, *args, **kwargs)


class ChannelProductImageEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/product_images",
                         model=ProductImage, *args, **kwargs)


class ChannelOrderEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/orders",
                         model=Order, *args, **kwargs)


class ChannelCreateOrderEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/create_orders",
                         model=Order, *args, **kwargs)


class ChannelPriceListEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/price_lists",
                         model=PriceList, *args, **kwargs)


class ChannelStockListEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/stock_lists",
                         model=StockList, *args, **kwargs)


class ChannelCargoEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/cargos",
                         model=CargoCompany, *args, **kwargs)


class ChannelCustomerEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/customers",
                         model=Customer, *args, **kwargs)


class ChannelCountryEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/countries",
                         model=Country, *args, **kwargs)


class ChannelCityEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/cities",
                         model=City, *args, **kwargs)


class ChannelTownshipEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/townships",
                         model=Township, *args, **kwargs)


class ChannelDistrictEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/districts",
                         model=District, *args, **kwargs)


class ChannelAddressEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/addresses",
                         model=Address, *args, **kwargs)


class ChannelOrderShippingInfoEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/order_shipping_infos",
                         model=Address, *args, **kwargs)


class ChannelErrorReportEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/error_reports",
                         model=ErrorReport, *args, **kwargs)


class ChannelOrderItemEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/order_items",
                         model=OrderItem, *args, **kwargs)


class ChannelProductCategoryEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/product_categories",
                         model=ProductCategory, *args, **kwargs)


class ChannelExtraProductPriceEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/extra_product_prices",
                         model=ProductPrice, *args, **kwargs)


class ChannelExtraProductStockEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/extra_product_stocks",
                         model=ProductStock, *args, **kwargs)


class ChannelRetailStoreEndpoint(OmnitronApiEndpoint):
    def __init__(self, *args, **kwargs):
        super().__init__(endpoint="channel/{channel_id}/retail_stores",
                         model=RetailStore, *args, **kwargs)



from __future__ import unicode_literals

from .base import OmniSDKTestCase


class AuthTestCase(OmniSDKTestCase):
    def test_omnitron_successful_auth(self):
        self.omnisdk.omnitron_client(self.creds.url, self.creds.username, self.creds.password)

    def test_omnitron_unsuccessful_auth(self):
        with self.assertRaises(self.omnisdk.validation_error):
            self.omnisdk.omnitron_client(self.creds.url, "", "")

    def test_integration_successful_auth(self):
        self.omnisdk.integration_client(self.creds.url, self.creds.username, self.creds.password)

    def test_integration_unsuccessful_auth(self):
        with self.assertRaises(self.omnisdk.validation_error):
            self.omnisdk.integration_client(self.creds.url, "", "")

    def test_key_refreshed_automatically(self):
        pass



from __future__ import unicode_literals

from .base import OmniSDKTestCase

# TODO add tests
class ApiEndpointTestCase(OmniSDKTestCase):
    def test_endpoint_url_is_correct(self):
        pass

    def test_create(self):
        pass

    def test_retrieve(self):
        pass

    def test_update(self):
        pass

    def test_delete(self):
        pass

    def test_list(self):
        pass
